/*
 *  Copyright 2001-2013 Stephen Colebourne
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.joda.beans.gen;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.Set;

import org.joda.beans.Bean;
import org.joda.beans.BeanDefinition;
import org.joda.beans.ImmutableBean;
import org.joda.beans.JodaBeanUtils;
import org.joda.beans.MetaProperty;
import org.joda.beans.Property;
import org.joda.beans.PropertyDefinition;
import org.joda.beans.impl.BasicImmutableBeanBuilder;
import org.joda.beans.impl.direct.DirectMetaBean;
import org.joda.beans.impl.direct.DirectMetaProperty;
import org.joda.beans.impl.direct.DirectMetaPropertyMap;

import com.google.common.collect.ImmutableMap;

/**
 * Mock address JavaBean, used for testing.
 * 
 * @author Stephen Colebourne
 */
@BeanDefinition
public final class ImmAddress implements ImmutableBean {

    /**
     * The number.
     * This will be the flat, house number or house name.
     */
    @PropertyDefinition
    private final int number;
    /**
     * The street.
     */
    @PropertyDefinition(validate = "notNull")
    private final String street;
    /**
     * The city.
     */
    @PropertyDefinition(validate = "notNull")
    private final String city;
    /**
     * The extra data.
     */
    @PropertyDefinition
    private final byte[] data;
    /**
     * The owner.
     */
    @PropertyDefinition(validate = "notNull")
    private final ImmPerson owner;
    /**
     * The list in map field.
     */
    @PropertyDefinition(validate = "notNull")
    private final ImmutableMap<String, List<String>> listInMap;
    /**
     * The list in map field.
     */
    @PropertyDefinition(validate = "notNull")
    private final ImmutableMap<String, List<Integer>> listNumericInMap;
    /**
     * The list in map field.
     */
    @PropertyDefinition(validate = "notNull")
    private final ImmutableMap<String, List<List<Integer>>> listInListInMap;
    /**
     * The map in map field.
     */
    @PropertyDefinition(validate = "notNull")
    private final ImmutableMap<ImmPerson, Map<String, ImmPerson>> mapInMap;
    /**
     * The bean key and bean value field.
     */
    @PropertyDefinition(validate = "notNull")
    private final ImmutableMap<ImmPerson, ImmAddress> beanBeanMap;

    //------------------------- AUTOGENERATED START -------------------------
    ///CLOVER:OFF
    /**
     * The meta-bean for {@code ImmAddress}.
     * @return the meta-bean, not null
     */
    public static ImmAddress.Meta meta() {
        return ImmAddress.Meta.INSTANCE;
    }

    static {
        JodaBeanUtils.registerMetaBean(ImmAddress.Meta.INSTANCE);
    }

    /**
     * Returns a builder used to create an instance of the bean.
     *
     * @return the builder, not null
     */
    public static ImmAddress.Builder builder() {
        return new ImmAddress.Builder();
    }

    private ImmAddress(
            int number,
            String street,
            String city,
            byte[] data,
            ImmPerson owner,
            Map<String, List<String>> listInMap,
            Map<String, List<Integer>> listNumericInMap,
            Map<String, List<List<Integer>>> listInListInMap,
            Map<ImmPerson, Map<String, ImmPerson>> mapInMap,
            Map<ImmPerson, ImmAddress> beanBeanMap) {
        JodaBeanUtils.notNull(street, "street");
        JodaBeanUtils.notNull(city, "city");
        JodaBeanUtils.notNull(owner, "owner");
        JodaBeanUtils.notNull(listInMap, "listInMap");
        JodaBeanUtils.notNull(listNumericInMap, "listNumericInMap");
        JodaBeanUtils.notNull(listInListInMap, "listInListInMap");
        JodaBeanUtils.notNull(mapInMap, "mapInMap");
        JodaBeanUtils.notNull(beanBeanMap, "beanBeanMap");
        this.number = number;
        this.street = street;
        this.city = city;
        this.data = (data != null ? data.clone() : null);
        this.owner = owner;
        this.listInMap = ImmutableMap.copyOf(listInMap);
        this.listNumericInMap = ImmutableMap.copyOf(listNumericInMap);
        this.listInListInMap = ImmutableMap.copyOf(listInListInMap);
        this.mapInMap = ImmutableMap.copyOf(mapInMap);
        this.beanBeanMap = ImmutableMap.copyOf(beanBeanMap);
    }

    @Override
    public ImmAddress.Meta metaBean() {
        return ImmAddress.Meta.INSTANCE;
    }

    @Override
    public <R> Property<R> property(String propertyName) {
        return metaBean().<R>metaProperty(propertyName).createProperty(this);
    }

    @Override
    public Set<String> propertyNames() {
        return metaBean().metaPropertyMap().keySet();
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the number.
     * This will be the flat, house number or house name.
     * @return the value of the property
     */
    public int getNumber() {
        return number;
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the street.
     * @return the value of the property, not null
     */
    public String getStreet() {
        return street;
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the city.
     * @return the value of the property, not null
     */
    public String getCity() {
        return city;
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the extra data.
     * @return the value of the property
     */
    public byte[] getData() {
        return (data != null ? data.clone() : null);
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the owner.
     * @return the value of the property, not null
     */
    public ImmPerson getOwner() {
        return owner;
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the list in map field.
     * @return the value of the property, not null
     */
    public ImmutableMap<String, List<String>> getListInMap() {
        return listInMap;
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the list in map field.
     * @return the value of the property, not null
     */
    public ImmutableMap<String, List<Integer>> getListNumericInMap() {
        return listNumericInMap;
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the list in map field.
     * @return the value of the property, not null
     */
    public ImmutableMap<String, List<List<Integer>>> getListInListInMap() {
        return listInListInMap;
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the map in map field.
     * @return the value of the property, not null
     */
    public ImmutableMap<ImmPerson, Map<String, ImmPerson>> getMapInMap() {
        return mapInMap;
    }

    //-----------------------------------------------------------------------
    /**
     * Gets the bean key and bean value field.
     * @return the value of the property, not null
     */
    public ImmutableMap<ImmPerson, ImmAddress> getBeanBeanMap() {
        return beanBeanMap;
    }

    //-----------------------------------------------------------------------
    /**
     * Returns a builder that allows this bean to be mutated.
     * @return the mutable builder, not null
     */
    public Builder toBuilder() {
        return new Builder(this);
    }

    @Override
    public ImmAddress clone() {
        return this;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj != null && obj.getClass() == this.getClass()) {
            ImmAddress other = (ImmAddress) obj;
            return (getNumber() == other.getNumber()) &&
                    JodaBeanUtils.equal(getStreet(), other.getStreet()) &&
                    JodaBeanUtils.equal(getCity(), other.getCity()) &&
                    JodaBeanUtils.equal(getData(), other.getData()) &&
                    JodaBeanUtils.equal(getOwner(), other.getOwner()) &&
                    JodaBeanUtils.equal(getListInMap(), other.getListInMap()) &&
                    JodaBeanUtils.equal(getListNumericInMap(), other.getListNumericInMap()) &&
                    JodaBeanUtils.equal(getListInListInMap(), other.getListInListInMap()) &&
                    JodaBeanUtils.equal(getMapInMap(), other.getMapInMap()) &&
                    JodaBeanUtils.equal(getBeanBeanMap(), other.getBeanBeanMap());
        }
        return false;
    }

    @Override
    public int hashCode() {
        int hash = getClass().hashCode();
        hash += hash * 31 + JodaBeanUtils.hashCode(getNumber());
        hash += hash * 31 + JodaBeanUtils.hashCode(getStreet());
        hash += hash * 31 + JodaBeanUtils.hashCode(getCity());
        hash += hash * 31 + JodaBeanUtils.hashCode(getData());
        hash += hash * 31 + JodaBeanUtils.hashCode(getOwner());
        hash += hash * 31 + JodaBeanUtils.hashCode(getListInMap());
        hash += hash * 31 + JodaBeanUtils.hashCode(getListNumericInMap());
        hash += hash * 31 + JodaBeanUtils.hashCode(getListInListInMap());
        hash += hash * 31 + JodaBeanUtils.hashCode(getMapInMap());
        hash += hash * 31 + JodaBeanUtils.hashCode(getBeanBeanMap());
        return hash;
    }

    @Override
    public String toString() {
        StringBuilder buf = new StringBuilder(352);
        buf.append("ImmAddress{");
        buf.append("number").append('=').append(getNumber()).append(',').append(' ');
        buf.append("street").append('=').append(getStreet()).append(',').append(' ');
        buf.append("city").append('=').append(getCity()).append(',').append(' ');
        buf.append("data").append('=').append(getData()).append(',').append(' ');
        buf.append("owner").append('=').append(getOwner()).append(',').append(' ');
        buf.append("listInMap").append('=').append(getListInMap()).append(',').append(' ');
        buf.append("listNumericInMap").append('=').append(getListNumericInMap()).append(',').append(' ');
        buf.append("listInListInMap").append('=').append(getListInListInMap()).append(',').append(' ');
        buf.append("mapInMap").append('=').append(getMapInMap()).append(',').append(' ');
        buf.append("beanBeanMap").append('=').append(JodaBeanUtils.toString(getBeanBeanMap()));
        buf.append('}');
        return buf.toString();
    }

    //-----------------------------------------------------------------------
    /**
     * The meta-bean for {@code ImmAddress}.
     */
    public static final class Meta extends DirectMetaBean {
        /**
         * The singleton instance of the meta-bean.
         */
        static final Meta INSTANCE = new Meta();

        /**
         * The meta-property for the {@code number} property.
         */
        private final MetaProperty<Integer> number = DirectMetaProperty.ofImmutable(
                this, "number", ImmAddress.class, Integer.TYPE);
        /**
         * The meta-property for the {@code street} property.
         */
        private final MetaProperty<String> street = DirectMetaProperty.ofImmutable(
                this, "street", ImmAddress.class, String.class);
        /**
         * The meta-property for the {@code city} property.
         */
        private final MetaProperty<String> city = DirectMetaProperty.ofImmutable(
                this, "city", ImmAddress.class, String.class);
        /**
         * The meta-property for the {@code data} property.
         */
        private final MetaProperty<byte[]> data = DirectMetaProperty.ofImmutable(
                this, "data", ImmAddress.class, byte[].class);
        /**
         * The meta-property for the {@code owner} property.
         */
        private final MetaProperty<ImmPerson> owner = DirectMetaProperty.ofImmutable(
                this, "owner", ImmAddress.class, ImmPerson.class);
        /**
         * The meta-property for the {@code listInMap} property.
         */
        @SuppressWarnings({"unchecked", "rawtypes" })
        private final MetaProperty<ImmutableMap<String, List<String>>> listInMap = DirectMetaProperty.ofImmutable(
                this, "listInMap", ImmAddress.class, (Class) ImmutableMap.class);
        /**
         * The meta-property for the {@code listNumericInMap} property.
         */
        @SuppressWarnings({"unchecked", "rawtypes" })
        private final MetaProperty<ImmutableMap<String, List<Integer>>> listNumericInMap = DirectMetaProperty.ofImmutable(
                this, "listNumericInMap", ImmAddress.class, (Class) ImmutableMap.class);
        /**
         * The meta-property for the {@code listInListInMap} property.
         */
        @SuppressWarnings({"unchecked", "rawtypes" })
        private final MetaProperty<ImmutableMap<String, List<List<Integer>>>> listInListInMap = DirectMetaProperty.ofImmutable(
                this, "listInListInMap", ImmAddress.class, (Class) ImmutableMap.class);
        /**
         * The meta-property for the {@code mapInMap} property.
         */
        @SuppressWarnings({"unchecked", "rawtypes" })
        private final MetaProperty<ImmutableMap<ImmPerson, Map<String, ImmPerson>>> mapInMap = DirectMetaProperty.ofImmutable(
                this, "mapInMap", ImmAddress.class, (Class) ImmutableMap.class);
        /**
         * The meta-property for the {@code beanBeanMap} property.
         */
        @SuppressWarnings({"unchecked", "rawtypes" })
        private final MetaProperty<ImmutableMap<ImmPerson, ImmAddress>> beanBeanMap = DirectMetaProperty.ofImmutable(
                this, "beanBeanMap", ImmAddress.class, (Class) ImmutableMap.class);
        /**
         * The meta-properties.
         */
        private final Map<String, MetaProperty<?>> metaPropertyMap$ = new DirectMetaPropertyMap(
                this, null,
                "number",
                "street",
                "city",
                "data",
                "owner",
                "listInMap",
                "listNumericInMap",
                "listInListInMap",
                "mapInMap",
                "beanBeanMap");

        /**
         * Restricted constructor.
         */
        protected Meta() {
        }

        @Override
        protected MetaProperty<?> metaPropertyGet(String propertyName) {
            switch (propertyName.hashCode()) {
                case -1034364087:  // number
                    return number;
                case -891990013:  // street
                    return street;
                case 3053931:  // city
                    return city;
                case 3076010:  // data
                    return data;
                case 106164915:  // owner
                    return owner;
                case -1244601351:  // listInMap
                    return listInMap;
                case 391098024:  // listNumericInMap
                    return listNumericInMap;
                case -940836650:  // listInListInMap
                    return listInListInMap;
                case 158545403:  // mapInMap
                    return mapInMap;
                case -2039203396:  // beanBeanMap
                    return beanBeanMap;
            }
            return super.metaPropertyGet(propertyName);
        }

        @Override
        public ImmAddress.Builder builder() {
            return new ImmAddress.Builder();
        }

        @Override
        public Class<? extends ImmAddress> beanType() {
            return ImmAddress.class;
        }

        @Override
        public Map<String, MetaProperty<?>> metaPropertyMap() {
            return metaPropertyMap$;
        }

        //-----------------------------------------------------------------------
        /**
         * The meta-property for the {@code number} property.
         * @return the meta-property, not null
         */
        public MetaProperty<Integer> number() {
            return number;
        }

        /**
         * The meta-property for the {@code street} property.
         * @return the meta-property, not null
         */
        public MetaProperty<String> street() {
            return street;
        }

        /**
         * The meta-property for the {@code city} property.
         * @return the meta-property, not null
         */
        public MetaProperty<String> city() {
            return city;
        }

        /**
         * The meta-property for the {@code data} property.
         * @return the meta-property, not null
         */
        public MetaProperty<byte[]> data() {
            return data;
        }

        /**
         * The meta-property for the {@code owner} property.
         * @return the meta-property, not null
         */
        public MetaProperty<ImmPerson> owner() {
            return owner;
        }

        /**
         * The meta-property for the {@code listInMap} property.
         * @return the meta-property, not null
         */
        public MetaProperty<ImmutableMap<String, List<String>>> listInMap() {
            return listInMap;
        }

        /**
         * The meta-property for the {@code listNumericInMap} property.
         * @return the meta-property, not null
         */
        public MetaProperty<ImmutableMap<String, List<Integer>>> listNumericInMap() {
            return listNumericInMap;
        }

        /**
         * The meta-property for the {@code listInListInMap} property.
         * @return the meta-property, not null
         */
        public MetaProperty<ImmutableMap<String, List<List<Integer>>>> listInListInMap() {
            return listInListInMap;
        }

        /**
         * The meta-property for the {@code mapInMap} property.
         * @return the meta-property, not null
         */
        public MetaProperty<ImmutableMap<ImmPerson, Map<String, ImmPerson>>> mapInMap() {
            return mapInMap;
        }

        /**
         * The meta-property for the {@code beanBeanMap} property.
         * @return the meta-property, not null
         */
        public MetaProperty<ImmutableMap<ImmPerson, ImmAddress>> beanBeanMap() {
            return beanBeanMap;
        }

        //-----------------------------------------------------------------------
        @Override
        protected Object propertyGet(Bean bean, String propertyName, boolean quiet) {
            switch (propertyName.hashCode()) {
                case -1034364087:  // number
                    return ((ImmAddress) bean).getNumber();
                case -891990013:  // street
                    return ((ImmAddress) bean).getStreet();
                case 3053931:  // city
                    return ((ImmAddress) bean).getCity();
                case 3076010:  // data
                    return ((ImmAddress) bean).getData();
                case 106164915:  // owner
                    return ((ImmAddress) bean).getOwner();
                case -1244601351:  // listInMap
                    return ((ImmAddress) bean).getListInMap();
                case 391098024:  // listNumericInMap
                    return ((ImmAddress) bean).getListNumericInMap();
                case -940836650:  // listInListInMap
                    return ((ImmAddress) bean).getListInListInMap();
                case 158545403:  // mapInMap
                    return ((ImmAddress) bean).getMapInMap();
                case -2039203396:  // beanBeanMap
                    return ((ImmAddress) bean).getBeanBeanMap();
            }
            return super.propertyGet(bean, propertyName, quiet);
        }

        @Override
        protected void propertySet(Bean bean, String propertyName, Object newValue, boolean quiet) {
            metaProperty(propertyName);
            if (quiet) {
                return;
            }
            throw new UnsupportedOperationException("Property cannot be written: " + propertyName);
        }

    }

    //-----------------------------------------------------------------------
    /**
     * The bean-builder for {@code ImmAddress}.
     */
    public static final class Builder extends BasicImmutableBeanBuilder<ImmAddress> {

        private int number;
        private String street;
        private String city;
        private byte[] data;
        private ImmPerson owner;
        private Map<String, List<String>> listInMap = new HashMap<String, List<String>>();
        private Map<String, List<Integer>> listNumericInMap = new HashMap<String, List<Integer>>();
        private Map<String, List<List<Integer>>> listInListInMap = new HashMap<String, List<List<Integer>>>();
        private Map<ImmPerson, Map<String, ImmPerson>> mapInMap = new HashMap<ImmPerson, Map<String, ImmPerson>>();
        private Map<ImmPerson, ImmAddress> beanBeanMap = new HashMap<ImmPerson, ImmAddress>();

        /**
         * Restricted constructor.
         */
        private Builder() {
            super(ImmAddress.Meta.INSTANCE);
        }

        /**
         * Restricted copy constructor.
         * @param beanToCopy  the bean to copy from, not null
         */
        private Builder(ImmAddress beanToCopy) {
            super(ImmAddress.Meta.INSTANCE);
            this.number = beanToCopy.getNumber();
            this.street = beanToCopy.getStreet();
            this.city = beanToCopy.getCity();
            this.data = (beanToCopy.getData() != null ? beanToCopy.getData().clone() : null);
            this.owner = beanToCopy.getOwner();
            this.listInMap = new HashMap<String, List<String>>(beanToCopy.getListInMap());
            this.listNumericInMap = new HashMap<String, List<Integer>>(beanToCopy.getListNumericInMap());
            this.listInListInMap = new HashMap<String, List<List<Integer>>>(beanToCopy.getListInListInMap());
            this.mapInMap = new HashMap<ImmPerson, Map<String, ImmPerson>>(beanToCopy.getMapInMap());
            this.beanBeanMap = new HashMap<ImmPerson, ImmAddress>(beanToCopy.getBeanBeanMap());
        }

        //-----------------------------------------------------------------------
        @SuppressWarnings("unchecked")
        @Override
        public Builder set(String propertyName, Object newValue) {
            switch (propertyName.hashCode()) {
                case -1034364087:  // number
                    this.number = (Integer) newValue;
                    break;
                case -891990013:  // street
                    this.street = (String) newValue;
                    break;
                case 3053931:  // city
                    this.city = (String) newValue;
                    break;
                case 3076010:  // data
                    this.data = (byte[]) newValue;
                    break;
                case 106164915:  // owner
                    this.owner = (ImmPerson) newValue;
                    break;
                case -1244601351:  // listInMap
                    this.listInMap = (Map<String, List<String>>) newValue;
                    break;
                case 391098024:  // listNumericInMap
                    this.listNumericInMap = (Map<String, List<Integer>>) newValue;
                    break;
                case -940836650:  // listInListInMap
                    this.listInListInMap = (Map<String, List<List<Integer>>>) newValue;
                    break;
                case 158545403:  // mapInMap
                    this.mapInMap = (Map<ImmPerson, Map<String, ImmPerson>>) newValue;
                    break;
                case -2039203396:  // beanBeanMap
                    this.beanBeanMap = (Map<ImmPerson, ImmAddress>) newValue;
                    break;
                default:
                    throw new NoSuchElementException("Unknown property: " + propertyName);
            }
            return this;
        }

        @Override
        public ImmAddress build() {
            return new ImmAddress(
                    number,
                    street,
                    city,
                    data,
                    owner,
                    listInMap,
                    listNumericInMap,
                    listInListInMap,
                    mapInMap,
                    beanBeanMap);
        }

        //-----------------------------------------------------------------------
        /**
         * Sets the {@code number} property in the builder.
         * @param number  the new value
         * @return this, for chaining, not null
         */
        public Builder number(int number) {
            this.number = number;
            return this;
        }

        /**
         * Sets the {@code street} property in the builder.
         * @param street  the new value, not null
         * @return this, for chaining, not null
         */
        public Builder street(String street) {
            JodaBeanUtils.notNull(street, "street");
            this.street = street;
            return this;
        }

        /**
         * Sets the {@code city} property in the builder.
         * @param city  the new value, not null
         * @return this, for chaining, not null
         */
        public Builder city(String city) {
            JodaBeanUtils.notNull(city, "city");
            this.city = city;
            return this;
        }

        /**
         * Sets the {@code data} property in the builder.
         * @param data  the new value
         * @return this, for chaining, not null
         */
        public Builder data(byte[] data) {
            this.data = data;
            return this;
        }

        /**
         * Sets the {@code owner} property in the builder.
         * @param owner  the new value, not null
         * @return this, for chaining, not null
         */
        public Builder owner(ImmPerson owner) {
            JodaBeanUtils.notNull(owner, "owner");
            this.owner = owner;
            return this;
        }

        /**
         * Sets the {@code listInMap} property in the builder.
         * @param listInMap  the new value, not null
         * @return this, for chaining, not null
         */
        public Builder listInMap(Map<String, List<String>> listInMap) {
            JodaBeanUtils.notNull(listInMap, "listInMap");
            this.listInMap = listInMap;
            return this;
        }

        /**
         * Sets the {@code listNumericInMap} property in the builder.
         * @param listNumericInMap  the new value, not null
         * @return this, for chaining, not null
         */
        public Builder listNumericInMap(Map<String, List<Integer>> listNumericInMap) {
            JodaBeanUtils.notNull(listNumericInMap, "listNumericInMap");
            this.listNumericInMap = listNumericInMap;
            return this;
        }

        /**
         * Sets the {@code listInListInMap} property in the builder.
         * @param listInListInMap  the new value, not null
         * @return this, for chaining, not null
         */
        public Builder listInListInMap(Map<String, List<List<Integer>>> listInListInMap) {
            JodaBeanUtils.notNull(listInListInMap, "listInListInMap");
            this.listInListInMap = listInListInMap;
            return this;
        }

        /**
         * Sets the {@code mapInMap} property in the builder.
         * @param mapInMap  the new value, not null
         * @return this, for chaining, not null
         */
        public Builder mapInMap(Map<ImmPerson, Map<String, ImmPerson>> mapInMap) {
            JodaBeanUtils.notNull(mapInMap, "mapInMap");
            this.mapInMap = mapInMap;
            return this;
        }

        /**
         * Sets the {@code beanBeanMap} property in the builder.
         * @param beanBeanMap  the new value, not null
         * @return this, for chaining, not null
         */
        public Builder beanBeanMap(Map<ImmPerson, ImmAddress> beanBeanMap) {
            JodaBeanUtils.notNull(beanBeanMap, "beanBeanMap");
            this.beanBeanMap = beanBeanMap;
            return this;
        }

        //-----------------------------------------------------------------------
        @Override
        public String toString() {
            StringBuilder buf = new StringBuilder(352);
            buf.append("ImmAddress.Builder{");
            buf.append("number").append('=').append(number).append(',').append(' ');
            buf.append("street").append('=').append(street).append(',').append(' ');
            buf.append("city").append('=').append(city).append(',').append(' ');
            buf.append("data").append('=').append(data).append(',').append(' ');
            buf.append("owner").append('=').append(owner).append(',').append(' ');
            buf.append("listInMap").append('=').append(listInMap).append(',').append(' ');
            buf.append("listNumericInMap").append('=').append(listNumericInMap).append(',').append(' ');
            buf.append("listInListInMap").append('=').append(listInListInMap).append(',').append(' ');
            buf.append("mapInMap").append('=').append(mapInMap).append(',').append(' ');
            buf.append("beanBeanMap").append('=').append(beanBeanMap);
            buf.append('}');
            return buf.toString();
        }

    }

    ///CLOVER:ON
    //-------------------------- AUTOGENERATED END --------------------------
}
